"""
Fallback directory information.

This file is auto-generated by scripts/update_authorities.py
Do not edit manually.

Fallback directories are stable relays that can be used for
bootstrapping when directory authorities are unreachable.
"""

# pylint: disable=too-many-lines

import random
from dataclasses import dataclass


@dataclass
class FallbackDirectory:
    """Fallback directory information."""

    ip: str
    orport: int
    fingerprint: str  # hex fingerprint
    nickname: str | None = None
    ipv6_address: str | None = None

    @property
    def address(self) -> str:
        """Get formatted address string."""
        return f"{self.ip}:{self.orport}"


FALLBACK_DIRECTORIES = [
    FallbackDirectory(
        ip="45.155.249.124",
        orport=38017,
        fingerprint="4BCB5FC1BE126EF5302447472930A9034070FB08",
        nickname="ZhiliTORNode",
    ),
    FallbackDirectory(
        ip="124.198.131.138",
        orport=80,
        fingerprint="47B56BBC6573EA37A886736145EBB5D6F3EC7480",
        nickname="PlayInTraffic",
    ),
    FallbackDirectory(
        ip="185.235.146.29",
        orport=443,
        fingerprint="5A6976353F19DAB6EB63A2CB95C00039B7D4064A",
        nickname="mwittig1",
        ipv6_address="[2a10:8a40:f313::29]:443",
    ),
    FallbackDirectory(
        ip="81.7.18.7",
        orport=9001,
        fingerprint="0C475BA4D3AA3C289B716F95954CAD616E50C4E5",
        nickname="Freebird32",
        ipv6_address="[2a02:180:6:1::2eee]:9001",
    ),
    FallbackDirectory(
        ip="188.214.88.33",
        orport=9001,
        fingerprint="BC5D9898817E3F07CDD4292B35DA6819368710B7",
        nickname="9u32bg93b2ug9",
    ),
    FallbackDirectory(
        ip="96.9.98.210",
        orport=443,
        fingerprint="9D98766220B32CBD882C1B799D20BE71C3BEAAF6",
        nickname="bigwalkdog",
    ),
    FallbackDirectory(
        ip="45.95.169.109",
        orport=7430,
        fingerprint="7C9FC7C99D7F83980E621BA8D4E0D40FCE53104F",
        nickname="Quetzalcoatl",
        ipv6_address="[2a0e:bfc0:0:14::24a8]:7430",
    ),
    FallbackDirectory(
        ip="192.42.116.214",
        orport=9000,
        fingerprint="31BA70D5332FE49C500FBFFDB0CC5B9D3803CFBF",
        nickname="NTH17R1",
        ipv6_address="[2001:67c:e60:c0c:192:42:116:214]:9000",
    ),
    FallbackDirectory(
        ip="91.208.75.153",
        orport=443,
        fingerprint="5952434A60B6881FFFAF5C3B1C08682FAF5885F5",
        nickname="Nobutomo",
    ),
    FallbackDirectory(
        ip="64.65.1.112",
        orport=443,
        fingerprint="56912E60E4E3003A277B9E46C7EFBC5E01C14C18",
        nickname="nlelamar",
    ),
    FallbackDirectory(
        ip="185.40.4.101",
        orport=13443,
        fingerprint="45FA08CC2A41FE183E4FF5DEDB3AAB13C01FAD39",
        nickname="bauruine",
        ipv6_address="[2a0e:4005:1002:ffff:185:40:4:101]:13443",
    ),
    FallbackDirectory(
        ip="64.65.0.7",
        orport=443,
        fingerprint="862F828CC223FF9916ADFCCEC47BC5E9839413BA",
        nickname="bodegabamz",
    ),
    FallbackDirectory(
        ip="64.65.62.202",
        orport=443,
        fingerprint="032E78EDF6708A3C70ABCC2AED9FAABDB7DB4C43",
        nickname="headieone",
    ),
    FallbackDirectory(
        ip="96.9.98.166",
        orport=443,
        fingerprint="6EF104C3EF66FA71669EE123CC05FEAEFB83A0A5",
        nickname="toosi",
    ),
    FallbackDirectory(
        ip="64.65.1.120",
        orport=443,
        fingerprint="3B0536A960098436EBF9C533711F0BD2C809364F",
        nickname="bigboogie",
    ),
    FallbackDirectory(
        ip="176.65.149.65",
        orport=443,
        fingerprint="3F8B4D9442218B3EA6CC8FD05E37E62B3E6AB361",
        nickname="Famy",
        ipv6_address="[2a05:b0c7:6acd::1]:443",
    ),
    FallbackDirectory(
        ip="45.138.16.107",
        orport=7100,
        fingerprint="64D90959E50D593D80ACD0E29A2BE9051EB66EEA",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:45:138:16:107]:7100",
    ),
    FallbackDirectory(
        ip="185.220.101.41",
        orport=10041,
        fingerprint="20209021CE8B8732F8EE57D313A36FF8DC823E5E",
        nickname="ForPrivacyNET",
        ipv6_address="[2a0b:f4c2:2::41]:10041",
    ),
    FallbackDirectory(
        ip="64.65.62.175",
        orport=443,
        fingerprint="CF64EF901AA72D9024B81DBA12DACC6BDF47608A",
        nickname="chinoxl",
    ),
    FallbackDirectory(
        ip="175.114.146.233",
        orport=9001,
        fingerprint="C51D9928A523C3218C1AF09C9450CEA93955E033",
        nickname="LEEJAEMYUNG",
    ),
    FallbackDirectory(
        ip="37.120.26.229",
        orport=9001,
        fingerprint="F864BDEB66C8A11E209456846499C2F995435797",
        nickname="torushopyard",
    ),
    FallbackDirectory(
        ip="45.137.70.158",
        orport=9001,
        fingerprint="B2E1BB031C2882A45E78D9A25A2D039A945378F5",
        nickname="Pjotrek",
        ipv6_address="[2a0e:97c0:3ea:882::1]:9001",
    ),
    FallbackDirectory(
        ip="213.239.215.221",
        orport=9001,
        fingerprint="021DDCD687FD505B7EA7E75DA6CEF0D778AA07FB",
        nickname="GrmmlDag",
        ipv6_address="[2a01:4f8:a0:90b0:789d:6a4:95f3:a78c]:9001",
    ),
    FallbackDirectory(
        ip="101.182.13.197",
        orport=9001,
        fingerprint="8541905725D75B320FACF0C588BA9562FE13BA09",
        nickname="datboigivesweb",
    ),
    FallbackDirectory(
        ip="194.164.245.205",
        orport=443,
        fingerprint="E4C6E31D745BE31F9E150F3BEEE19235D9629FC9",
        nickname="tetris",
        ipv6_address="[2a13:d207:0:40e::1]:443",
    ),
    FallbackDirectory(
        ip="207.153.6.185",
        orport=9001,
        fingerprint="9F8E87DD4B529B58608594AB9233C698BF7B1DEE",
        nickname="DefiantDave",
    ),
    FallbackDirectory(
        ip="194.34.132.169",
        orport=9001,
        fingerprint="6CB2C00C8374D6968698A57940245249FC5B1769",
        nickname="code",
    ),
    FallbackDirectory(
        ip="192.42.116.188",
        orport=22,
        fingerprint="7D9221E99110ED3A1A7E0086D68F920EF1D1DB8C",
        nickname="NTH36R1",
        ipv6_address="[2001:67c:e60:c0c:192:42:116:188]:22",
    ),
    FallbackDirectory(
        ip="45.11.59.28",
        orport=443,
        fingerprint="2FF8FFB28EAA635E291D623E03F231AC265F28F9",
        nickname="AnneMarie",
    ),
    FallbackDirectory(
        ip="192.42.116.189",
        orport=9006,
        fingerprint="5378983BC20642C22BD3A4DB04445F759EBC09E3",
        nickname="NTH37R7",
        ipv6_address="[2001:67c:e60:c0c:192:42:116:189]:9006",
    ),
    FallbackDirectory(
        ip="172.105.20.12",
        orport=443,
        fingerprint="D16D19ED2A8570242708BDABFDFCD7B9E484C8B0",
        nickname="linuxenbyEXIT4",
        ipv6_address="[2600:3c04::f03c:95ff:fe41:d42c]:443",
    ),
    FallbackDirectory(
        ip="188.165.136.211",
        orport=8082,
        fingerprint="061273FD35AD52B31E087E60BBE9F9DA1E05C1A2",
        nickname="Patr",
    ),
    FallbackDirectory(
        ip="64.65.1.42",
        orport=443,
        fingerprint="CE683BCD381A6FBA85B21CF39082C7A79A43DEF8",
        nickname="fabod4l",
    ),
    FallbackDirectory(
        ip="216.73.159.101",
        orport=9001,
        fingerprint="FF03BE4E8F9E7E41E2C7D9682CE4D6496FEE0621",
        nickname="DareDevil",
    ),
    FallbackDirectory(
        ip="162.55.107.247",
        orport=9001,
        fingerprint="675CFAC38BE3C9A26C3A2DD7CBC0E616F68624CA",
        nickname="mullbinde5",
        ipv6_address="[2a01:4f8:2191:3003:3::8]:9001",
    ),
    FallbackDirectory(
        ip="152.53.115.49",
        orport=9001,
        fingerprint="20B31CF54C093348A2D427DD1EBA26EFF998FB78",
        nickname="TorZurFreiheit1",
        ipv6_address="[2a0a:4cc0:80:47a3::2]:443",
    ),
    FallbackDirectory(
        ip="82.165.21.136",
        orport=9001,
        fingerprint="024BEAF1A4B3F01BB7DCC36402EC8764816129D5",
        nickname="mindbyte",
    ),
    FallbackDirectory(
        ip="185.82.126.57",
        orport=443,
        fingerprint="FFAF2849EED3BBB66031173551CFD5E39ECEA324",
        nickname="wfaegfyFDRTlhdtr",
    ),
    FallbackDirectory(
        ip="146.190.224.96",
        orport=9001,
        fingerprint="D70CADC1A398D9ACC28909C09B160DAEF59384CF",
        nickname="slarty2",
        ipv6_address="[2a03:b0c0:2:d0::14cb:6001]:9001",
    ),
    FallbackDirectory(
        ip="102.211.56.200",
        orport=9003,
        fingerprint="C616C915A423BE7DAD47C233E199746CB886CF4E",
        nickname="obzgs5tbmn4q",
    ),
    FallbackDirectory(
        ip="51.68.181.54",
        orport=9004,
        fingerprint="575B47977496E830DF5334F1A2266F16E028CB4B",
        nickname="QuackyForPrivacy",
    ),
    FallbackDirectory(
        ip="154.53.58.161",
        orport=7430,
        fingerprint="BAB2CDAE807EFC4710485F78E8ED359F22C67909",
        nickname="Quetzalcoatl",
        ipv6_address="[2605:a141:2261:4410::1]:7430",
    ),
    FallbackDirectory(
        ip="96.9.98.26",
        orport=443,
        fingerprint="D9B82D372FCA37F82058292FB44E229DE89EE0BE",
        nickname="peeweelongway",
    ),
    FallbackDirectory(
        ip="217.160.252.208",
        orport=9001,
        fingerprint="2E0973F2D6D62064A481F8031265F143210F3883",
        nickname="Wurzelrelay",
        ipv6_address="[2a01:239:28e:6100::1]:9001",
    ),
    FallbackDirectory(
        ip="64.65.0.33",
        orport=443,
        fingerprint="7EA091DF4CE4256ED35DC113D4921867CBF03A0E",
        nickname="megaran",
    ),
    FallbackDirectory(
        ip="23.129.64.145",
        orport=443,
        fingerprint="97A7D10BB2B886695BA766966DE897B5E8B74FB1",
        nickname="mudge",
        ipv6_address="[2620:18c:0:192::e0:145]:443",
    ),
    FallbackDirectory(
        ip="84.165.26.146",
        orport=9001,
        fingerprint="F5165CF26965A27C90B62B016141C60E3E6DD9F5",
        nickname="Unnamed",
    ),
    FallbackDirectory(
        ip="45.80.158.167",
        orport=9000,
        fingerprint="1133B20A95F051F65310C8A32DF92D04751F590C",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:45:80:158:167]:9000",
    ),
    FallbackDirectory(
        ip="94.16.115.121",
        orport=9001,
        fingerprint="936AAC50D69C9A3E3B37BA258156547F000C8D9D",
        nickname="LillyCL",
        ipv6_address="[2a03:4000:28:1e8::69]:9001",
    ),
    FallbackDirectory(
        ip="213.183.48.165",
        orport=443,
        fingerprint="4640014F4FD49FF14362C10A9C164A4392F4203B",
        nickname="swordsman",
    ),
    FallbackDirectory(
        ip="162.157.210.69",
        orport=9001,
        fingerprint="8997D74842F8104470418E8FCA7CF8D91F831ED7",
        nickname="Unnamed",
        ipv6_address="[2001:56a:fe40:da00::1337]:9001",
    ),
    FallbackDirectory(
        ip="107.189.1.9",
        orport=9100,
        fingerprint="43EF5141A4417D0BF1B0AB2AD2C3D74C22355D0A",
        nickname="Quetzalcoatl",
        ipv6_address="[2605:6400:30:f920:f523:28ef:3617:8b86]:9100",
    ),
    FallbackDirectory(
        ip="188.245.58.189",
        orport=9001,
        fingerprint="C988DA5E50FB7AF4B76AF66F19574E1921EE2A90",
        nickname="theBNrelay",
    ),
    FallbackDirectory(
        ip="209.114.126.206",
        orport=8080,
        fingerprint="4D2B729D92D699337A99F9A57530F538FD66F1F7",
        nickname="boxoffice206",
    ),
    FallbackDirectory(
        ip="185.241.208.71",
        orport=7100,
        fingerprint="10C079B536D3F682F8A1BB882DED61182646D167",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:185:241:208:71]:7100",
    ),
    FallbackDirectory(
        ip="45.83.104.137",
        orport=9100,
        fingerprint="359C5231AC2452D365B64A23C27817A1DFEE56B4",
        nickname="Aramis",
        ipv6_address="[2a03:4000:46:197:b434:d3ff:fe68:d9e1]:9100",
    ),
    FallbackDirectory(
        ip="104.244.79.50",
        orport=9100,
        fingerprint="C2808CAC0896D0AC4EFAAD4ECD467FE245CCFDF7",
        nickname="Quetzalcoatl",
        ipv6_address="[2605:6400:30:f08c:45b7:4a99:a154:694e]:9100",
    ),
    FallbackDirectory(
        ip="185.120.16.176",
        orport=9001,
        fingerprint="79D1CBF51A1FDD140E1733672EDF94C4C1E9C57D",
        nickname="Yuanshen",
    ),
    FallbackDirectory(
        ip="151.244.165.204",
        orport=9001,
        fingerprint="FF3769447DBD2010FE7F31AEC85D29B2B0A5D019",
        nickname="ThePartyBarn",
    ),
    FallbackDirectory(
        ip="173.255.228.134",
        orport=110,
        fingerprint="4ED33415952FA52DB95411A1DA86663EC1B109B9",
        nickname="bedrock",
        ipv6_address="[2600:3c03::f03c:91ff:fedf:407b]:110",
    ),
    FallbackDirectory(
        ip="96.9.98.17",
        orport=443,
        fingerprint="3A85C6698F4655A2127A07F19E8D6B8A489DB79C",
        nickname="jayworthy",
    ),
    FallbackDirectory(
        ip="64.65.1.100",
        orport=443,
        fingerprint="B7169F603A1FC8527C63A514010DE9B2590F093E",
        nickname="kennymuney",
    ),
    FallbackDirectory(
        ip="87.229.85.164",
        orport=58111,
        fingerprint="927BEE8EEC30D1456052972380861889A659CA21",
        nickname="WeaselWave",
    ),
    FallbackDirectory(
        ip="74.108.36.251",
        orport=9001,
        fingerprint="192B3306D8A064510CE6363D5AFFB563E789D246",
        nickname="LittleIsland",
    ),
    FallbackDirectory(
        ip="94.143.137.213",
        orport=443,
        fingerprint="CE4C88B2CA700655AC0CC98F093973EA86CAEE4D",
        nickname="versed03",
    ),
    FallbackDirectory(
        ip="147.135.129.138",
        orport=9500,
        fingerprint="69ADDE95173724077934D6932973E9BB7A40A3BB",
        nickname="prsv",
    ),
    FallbackDirectory(
        ip="194.14.0.243",
        orport=443,
        fingerprint="F7CC37F98E25E75EBC97BFD4FA7955053A0370BC",
        nickname="SrsTubesRelay02",
    ),
    FallbackDirectory(
        ip="81.174.250.136",
        orport=9001,
        fingerprint="87E4FAF25BE28DBD1FC1C9751F2F2D30694A815A",
        nickname="bik",
    ),
    FallbackDirectory(
        ip="172.105.6.34",
        orport=9001,
        fingerprint="D7F59CFB13A93E4C0BF867374B66547E226A7255",
        nickname="AndroidFighter",
        ipv6_address="[2600:3c04::f03c:93ff:fece:e1d1]:9050",
    ),
    FallbackDirectory(
        ip="92.60.38.94",
        orport=9001,
        fingerprint="DD0AA66DD9E4E71FFAFAB658DF8300F1CEEA0364",
        nickname="flowjob04",
        ipv6_address="[2a03:4000:33:1c9:68d7:eff:fe33:3593]:9001",
    ),
    FallbackDirectory(
        ip="195.47.238.178",
        orport=993,
        fingerprint="4BAE2F16CA87CDF0C7E32A11C6A1770EF30AC430",
        nickname="noack14i1",
        ipv6_address="[2a0c:5700:3133:4000:be24:11ff:fe3c:6727]:993",
    ),
    FallbackDirectory(
        ip="107.152.41.240",
        orport=9001,
        fingerprint="2FC20EF67366177AD0F207BFB425209C69A1C5ED",
        nickname="r1tordigi",
        ipv6_address="[2607:9000:0:35::3c1:df81]:9001",
    ),
    FallbackDirectory(
        ip="162.220.14.54",
        orport=9001,
        fingerprint="59F4DCD985864DFF877D5C9887C484F767CD098D",
        nickname="Cassanova",
        ipv6_address="[2604:a00:101:4:216:3eff:fe2f:1c84]:9001",
    ),
    FallbackDirectory(
        ip="194.15.115.91",
        orport=9001,
        fingerprint="5CC73850BA19AF390D7A57BBF2C1EF4BD3290BCD",
        nickname="WaterElementX",
    ),
    FallbackDirectory(
        ip="185.40.4.101",
        orport=8443,
        fingerprint="7A6C085A12D90C56C17A9D1A77D9D1D9B9E592D4",
        nickname="bauruine",
        ipv6_address="[2a0e:4005:1002:ffff:185:40:4:101]:8443",
    ),
    FallbackDirectory(
        ip="64.65.0.4",
        orport=443,
        fingerprint="79361CDC196241A74E50F74A164E8FEFB77C3EA2",
        nickname="shabaamsahdeeq",
    ),
    FallbackDirectory(
        ip="194.55.12.148",
        orport=9001,
        fingerprint="72270EB58EDEBE727AA29E67417628DBCE889FAE",
        nickname="giesskanne",
        ipv6_address="[2a03:4000:31:40:c48f:36ff:fec9:eaf6]:9001",
    ),
    FallbackDirectory(
        ip="51.77.132.82",
        orport=9600,
        fingerprint="1D96ECEECD5C62EA18FE95B61B5936447FA1178D",
        nickname="prsv",
        ipv6_address="[2001:41d0:303:8f52::1]:9600",
    ),
    FallbackDirectory(
        ip="166.84.6.10",
        orport=9001,
        fingerprint="D1F2155B38C21DAC4850C7F702E2946DBD8F5A1D",
        nickname="Unnamed",
        ipv6_address="[2602:f977:800:0:e076:63ff:fe06:2d0a]:9001",
    ),
    FallbackDirectory(
        ip="66.165.241.228",
        orport=9002,
        fingerprint="B2D0823FE5F9047C292B0412603F4801BCCABD07",
        nickname="skibble",
        ipv6_address="[2604:4500:8:14::4]:9002",
    ),
    FallbackDirectory(
        ip="45.95.169.110",
        orport=7430,
        fingerprint="88FA8CBAD03FD602D27985F0DF34FA5DAD9E7BB2",
        nickname="Quetzalcoatl",
        ipv6_address="[2a0e:bfc0:0:2::8a62]:7430",
    ),
    FallbackDirectory(
        ip="37.114.53.201",
        orport=9001,
        fingerprint="2F81B29080727EFF0505E2F66CBD6C1EF6F9F4A9",
        nickname="Ebert",
    ),
    FallbackDirectory(
        ip="64.65.1.169",
        orport=443,
        fingerprint="66653D72465EEA4DD9FC7EE5F09599C482897061",
        nickname="paulolondra",
    ),
    FallbackDirectory(
        ip="148.251.85.195",
        orport=9030,
        fingerprint="77A3ADC5D455778B53C2803761916DFB7DA0A790",
        nickname="redvader",
        ipv6_address="[2a01:4f8:202:6096::2]:9030",
    ),
    FallbackDirectory(
        ip="216.197.207.48",
        orport=9001,
        fingerprint="C366391E67A29CE959A15193D0CF2F9ED94F3578",
        nickname="jorcanada",
    ),
    FallbackDirectory(
        ip="185.195.71.244",
        orport=8443,
        fingerprint="AD86CD1A49573D52A7B6F4A35750F161AAD89C88",
        nickname="DigiGesTor1e2",
    ),
    FallbackDirectory(
        ip="23.92.19.230",
        orport=9001,
        fingerprint="2F67A940520D1C9E66497D3847F0FDEE545AE7C0",
        nickname="fpuzhpx",
        ipv6_address="[2600:3c03::f03c:91ff:fedb:19ed]:9001",
    ),
    FallbackDirectory(
        ip="124.198.132.172",
        orport=7100,
        fingerprint="77313C32AA48AB658299DA039DF6C627C126F570",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:11:1:124:198:132:172]:7100",
    ),
    FallbackDirectory(
        ip="83.228.199.230",
        orport=8443,
        fingerprint="6DF7E0D81F7A6CF573A27E35D942158063D497CC",
        nickname="Porridge",
        ipv6_address="[2001:1600:13:101::1c87]:8443",
    ),
    FallbackDirectory(
        ip="206.206.192.178",
        orport=9001,
        fingerprint="0C18DD2F789333989A70FDB94C1A3D0E6F8F4081",
        nickname="MiddleEarth",
    ),
    FallbackDirectory(
        ip="23.129.64.206",
        orport=443,
        fingerprint="F6399DB724C3F868833F38D701F0E311AB048BA8",
        nickname="eo206",
        ipv6_address="[2620:18c:0:192::e0:206]:443",
    ),
    FallbackDirectory(
        ip="142.93.228.59",
        orport=443,
        fingerprint="438731B8EFEDB1E592C8034934A55F532DEABAA9",
        nickname="WarheadRelay",
        ipv6_address="[2a03:b0c0:2:f0::1bc:9001]:443",
    ),
    FallbackDirectory(
        ip="71.19.146.15",
        orport=443,
        fingerprint="10F8A0A61A80ABDCD8BFBE9053F8FB2E0C507F71",
        nickname="flyDamFlowertrial",
        ipv6_address="[2605:2700:0:3:a800:ff:fe10:f0d3]:443",
    ),
    FallbackDirectory(
        ip="102.130.113.30",
        orport=9001,
        fingerprint="A4B2F2A51F73D408530FA6C8AF63A7FAFFDAA0FC",
        nickname="Lickitung",
    ),
    FallbackDirectory(
        ip="37.120.194.126",
        orport=443,
        fingerprint="90BBB469D7BD7E4BF80DB90BE2C01995C71D51EE",
        nickname="zarratrident",
    ),
    FallbackDirectory(
        ip="87.106.82.130",
        orport=9001,
        fingerprint="5B99771EB24027E47C04A6260492720C35CA1EDA",
        nickname="ADoorToTor",
    ),
    FallbackDirectory(
        ip="185.242.87.96",
        orport=9001,
        fingerprint="F4F5963A32DE2DB5C5F06261D86BEAED2A0587F9",
        nickname="RMC2",
    ),
    FallbackDirectory(
        ip="64.65.1.70",
        orport=443,
        fingerprint="798809E4A78F31D65235DC0E7EA7C02776E1437D",
        nickname="550madoff",
    ),
    FallbackDirectory(
        ip="171.25.193.78",
        orport=443,
        fingerprint="FDE127305CC410265E66BA82FB5A3E801BFD184E",
        nickname="DFRI17",
        ipv6_address="[2001:67c:289c:4::78]:443",
    ),
    FallbackDirectory(
        ip="45.141.215.56",
        orport=7430,
        fingerprint="719A124624725B23B8CE953BDA53860973EE10D8",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:45:141:215:56]:7430",
    ),
    FallbackDirectory(
        ip="64.65.1.33",
        orport=443,
        fingerprint="13A5BCAB9D08209FFE1A860FB4FEEF5B53D8C424",
        nickname="bankrollhayden",
    ),
    FallbackDirectory(
        ip="51.158.146.152",
        orport=443,
        fingerprint="55580D71B317A072F4A4DCF6EA4EDB015734AEE7",
        nickname="VeilsOfTheOnion",
        ipv6_address="[2001:bc8:6010:213:208:a2ff:fe0c:8128]:443",
    ),
    FallbackDirectory(
        ip="80.94.92.92",
        orport=9700,
        fingerprint="27F6AD0910BD90228C5D182F1F9BA199BAE54249",
        nickname="prsv",
    ),
    FallbackDirectory(
        ip="217.255.34.123",
        orport=9001,
        fingerprint="188673CF3937442517301800F383BE53D4A17732",
        nickname="TOPAS",
        ipv6_address="[2003:fd:5709:f700:e65f:1ff:fe00:96c5]:9001",
    ),
    FallbackDirectory(
        ip="45.9.156.105",
        orport=143,
        fingerprint="B9D49260B2EB896E0F7154523C1D7EE988A3CF5F",
        nickname="Quetzalcoatl",
        ipv6_address="[2a0e:bfc7::216:3cff:fe98:45cb]:143",
    ),
    FallbackDirectory(
        ip="185.165.171.84",
        orport=9001,
        fingerprint="4061C553CA88021B8302F0814365070AAE617270",
        nickname="TorExitRomania",
        ipv6_address="[2a06:1700:0:50::11]:9001",
    ),
    FallbackDirectory(
        ip="185.40.4.92",
        orport=13443,
        fingerprint="CF9A87A139A0D03AE7784F7D2DB4207665832A35",
        nickname="bauruine",
        ipv6_address="[2a0e:4005:1002:ffff:185:40:4:92]:13443",
    ),
    FallbackDirectory(
        ip="124.198.132.237",
        orport=9100,
        fingerprint="E86D16D2A0E3503E69971DE999989757C6931195",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:11:1:124:198:132:237]:9100",
    ),
    FallbackDirectory(
        ip="87.106.135.148",
        orport=443,
        fingerprint="1499D3B81B967C47F18AAC9C1C59576E8CF4F01D",
        nickname="PommespanzerDE5",
        ipv6_address="[2a01:239:319:100::1]:443",
    ),
    FallbackDirectory(
        ip="185.238.129.9",
        orport=9001,
        fingerprint="4E8CE6F5651E7342C1E7E5ED031E82078134FB0D",
        nickname="ymkeo",
        ipv6_address="[2a10:3781:116:1:ff:60ff:fe1e:4473]:9001",
    ),
    FallbackDirectory(
        ip="45.66.35.20",
        orport=1984,
        fingerprint="82E2708957A41EDA0819EE1C5FFC3E2DC38B9FE9",
        nickname="torexitams00",
        ipv6_address="[2a09:61c0::20]:1984",
    ),
    FallbackDirectory(
        ip="5.9.156.17",
        orport=443,
        fingerprint="AFFD147DBCC065A5CEF7258BC1367CC35855A431",
        nickname="Yahta4ee",
    ),
    FallbackDirectory(
        ip="193.189.100.204",
        orport=443,
        fingerprint="327DF526A04129C8AA55B5F3551BC46AC4BC7A6D",
        nickname="TORKeFFORG11",
        ipv6_address="[2a0f:df00:0:255::204]:443",
    ),
    FallbackDirectory(
        ip="158.69.252.116",
        orport=587,
        fingerprint="47A08224924CAAFEB8B8D81066ED007F4E68F2E1",
        nickname="vaahteranlehti",
        ipv6_address="[2607:5300:120:c74::1]:587",
    ),
    FallbackDirectory(
        ip="82.165.171.134",
        orport=443,
        fingerprint="BBC050C12E6A00D36384A23CEA901068F626B615",
        nickname="9g4net4",
        ipv6_address="[2001:ba0:24f:9a00::1]:443",
    ),
    FallbackDirectory(
        ip="94.130.142.182",
        orport=8443,
        fingerprint="50B7C4F6C18A3E5FC1D4E2ECE6B7B316B29FB26C",
        nickname="ElonTusk",
        ipv6_address="[2a01:4f8:13b:2dab::2]:8443",
    ),
    FallbackDirectory(
        ip="84.58.67.136",
        orport=9001,
        fingerprint="EA719AFF7AD3D20464EA4D41C297426C0D1B2071",
        nickname="SSTOR",
    ),
    FallbackDirectory(
        ip="64.65.1.63",
        orport=443,
        fingerprint="C9561E5C0709389715491346D8A22666247F90F8",
        nickname="scootywesson",
    ),
    FallbackDirectory(
        ip="84.226.186.33",
        orport=6969,
        fingerprint="AB40FD78D8A4DE530FB1E0355E74D80367784619",
        nickname="sig9eva",
        ipv6_address="[2001:1715:4e2b:a210:a3a:88ff:fe6e:d46b]:6969",
    ),
    FallbackDirectory(
        ip="23.105.174.243",
        orport=443,
        fingerprint="3BFB3C1C19B5E40D3889093DBD39000FE1D66FF3",
        nickname="BambooRat",
    ),
    FallbackDirectory(
        ip="5.196.131.170",
        orport=9001,
        fingerprint="4C8302C3A6C80081C12BC5A8F9A38917BD923FBE",
        nickname="Unnamed",
    ),
    FallbackDirectory(
        ip="67.186.0.207",
        orport=543,
        fingerprint="EF97A17973B7072C0E3CB2013A3EBAC42346FE42",
        nickname="JAJTorBits3",
        ipv6_address="[2601:547:c601:14a3::1000]:543",
    ),
    FallbackDirectory(
        ip="205.185.123.93",
        orport=9001,
        fingerprint="9C24A441000E6636D4041FFFD669C8DD16672CBC",
        nickname="clan",
    ),
    FallbackDirectory(
        ip="64.62.233.211",
        orport=443,
        fingerprint="32D25F437EB58E246D30AABBEB5D74B5034CB875",
        nickname="tonyd2",
    ),
    FallbackDirectory(
        ip="205.185.119.222",
        orport=443,
        fingerprint="6C620C35C0EA16657960882DE88B28968EBC8689",
        nickname="Cerberus",
        ipv6_address="[2605:6400:20:ae6:e6c6:d90:fee8:5ad5]:443",
    ),
    FallbackDirectory(
        ip="64.65.1.126",
        orport=443,
        fingerprint="53146879222C65C25F3C51002DC0CDF56B184F51",
        nickname="beaniesigel",
    ),
    FallbackDirectory(
        ip="212.51.149.67",
        orport=9001,
        fingerprint="E42DEAC28AB38BD89312FB92DA1B5D0CDC09386C",
        nickname="tetris",
    ),
    FallbackDirectory(
        ip="157.90.77.166",
        orport=9001,
        fingerprint="02A0D8DDF4DA4E601C1C66143BB0C8A0F2F3C857",
        nickname="changeme",
    ),
    FallbackDirectory(
        ip="185.220.101.36",
        orport=10136,
        fingerprint="C32905D18F2B0A104B039A10ED41C3D0C0BDF03A",
        nickname="ForPrivacyNET",
        ipv6_address="[2a0b:f4c2:2::36]:10136",
    ),
    FallbackDirectory(
        ip="45.14.233.204",
        orport=443,
        fingerprint="104AE1991C61426D9D3256758928B4CE6EF2AFAB",
        nickname="mikrogravitation4",
        ipv6_address="[2a0e:1580:1000:0:be24:11ff:fe60:2797]:443",
    ),
    FallbackDirectory(
        ip="91.219.236.101",
        orport=443,
        fingerprint="54FAC042C6F2FDEB449DD5B9EDE6833D155C538B",
        nickname="Lyle",
        ipv6_address="[2a10:c800:1:9cc6::1]:443",
    ),
    FallbackDirectory(
        ip="64.62.233.206",
        orport=9000,
        fingerprint="0833FA63031FD1007AAF386576B6CA2452460C5B",
        nickname="50cent3",
    ),
    FallbackDirectory(
        ip="140.238.97.211",
        orport=9001,
        fingerprint="0B53297F0BD687103A00A514E7D2AB83C70F3700",
        nickname="ruffletor",
    ),
    FallbackDirectory(
        ip="23.92.34.118",
        orport=443,
        fingerprint="3018498D945665829287BD9F59E7C8FFBA51830D",
        nickname="lauraschlessinger",
    ),
    FallbackDirectory(
        ip="185.107.57.64",
        orport=443,
        fingerprint="737BBB37E406B02EF8E38A54C3AB8AC2143069C9",
        nickname="eddy",
    ),
    FallbackDirectory(
        ip="64.62.233.204",
        orport=8443,
        fingerprint="272B6E6276D7AC4D63A9495461B5D7053B046E8E",
        nickname="kanyewest5",
    ),
    FallbackDirectory(
        ip="188.68.43.192",
        orport=9001,
        fingerprint="98867F5242505A2DD581C85B1CE256090B87F138",
        nickname="Piratenpartei03",
        ipv6_address="[2a03:4000:17:688:b854:7ff:fe48:bdcb]:9001",
    ),
    FallbackDirectory(
        ip="217.12.202.85",
        orport=443,
        fingerprint="E1DA0F90454AED535ACE9B415F78C1A1359E29A1",
        nickname="lyingbush",
        ipv6_address="[2a02:27aa::88]:443",
    ),
    FallbackDirectory(
        ip="179.43.158.176",
        orport=443,
        fingerprint="698B8708CF4EA02D27CA09274F3351B4F66A5834",
        nickname="greenlantern",
    ),
    FallbackDirectory(
        ip="160.119.249.24",
        orport=443,
        fingerprint="801EF80845848E685C4534A2408D32D5443187DF",
        nickname="montrose",
    ),
    FallbackDirectory(
        ip="185.241.208.115",
        orport=9100,
        fingerprint="F74A9BDD0CA2EFE07907D70AA18B43D923E3E745",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:185:241:208:115]:9100",
    ),
    FallbackDirectory(
        ip="45.86.86.150",
        orport=9696,
        fingerprint="8764E9BE25CE405C76E1DD0F0937D9BF6EA16A0C",
        nickname="FreedomForEveryone",
    ),
    FallbackDirectory(
        ip="94.142.241.41",
        orport=80,
        fingerprint="F04AC7D177EC79308D6959DBE042A247D9761635",
        nickname="NTH100R2",
    ),
    FallbackDirectory(
        ip="23.129.64.183",
        orport=443,
        fingerprint="8036F4287ED61CE0C42B5734F873EE79C0CC7E27",
        nickname="eo183",
        ipv6_address="[2620:18c:0:192::e0:183]:443",
    ),
    FallbackDirectory(
        ip="185.220.101.96",
        orport=443,
        fingerprint="52CD98902F6376E84DF2415B906F1426D585564D",
        nickname="Digitalcourage4ipaa",
        ipv6_address="[2a0b:f4c2:4::96]:443",
    ),
    FallbackDirectory(
        ip="31.133.0.210",
        orport=443,
        fingerprint="90705D63956EDD5904D173F1998F421C5FC5B6FC",
        nickname="MariePierre",
    ),
    FallbackDirectory(
        ip="94.230.208.148",
        orport=443,
        fingerprint="1BDBE9C0F7034E6789A9BF7BED82BE2045F0F5B7",
        nickname="DigiGesTor3e3",
        ipv6_address="[2a02:418:6017::148]:443",
    ),
    FallbackDirectory(
        ip="194.87.252.100",
        orport=1443,
        fingerprint="0625588B87F580A5B203A2C46020807860740662",
        nickname="Honos",
    ),
    FallbackDirectory(
        ip="109.69.218.176",
        orport=443,
        fingerprint="FA7136FD4F8A727810A22ED2096AF60F872C2F41",
        nickname="vandewoestijne",
    ),
    FallbackDirectory(
        ip="136.35.254.165",
        orport=999,
        fingerprint="DCC59C82C41C1E3E26BC4119D4CC579EF4B58391",
        nickname="AngryUnicorn",
    ),
    FallbackDirectory(
        ip="78.31.67.127",
        orport=9001,
        fingerprint="31A9565D0A51DD94EB81B6459C30276C5D790E20",
        nickname="mullbinde6",
        ipv6_address="[2001:4ba0:ffa4:413:200::208]:9001",
    ),
    FallbackDirectory(
        ip="89.58.5.0",
        orport=853,
        fingerprint="304EF9E012BE51190C6DDD5CFBAD8E3F3E875A43",
        nickname="TorRelay2c",
        ipv6_address="[2a03:4000:5e:c47::1]:853",
    ),
    FallbackDirectory(
        ip="174.160.2.27",
        orport=9001,
        fingerprint="8D7159CAB26F26A81A8A06A3BF5897576965E35E",
        nickname="AlliumAdPortum",
        ipv6_address="[2601:647:6701:5100:73b2:b84b:3c33:a8a1]:9001",
    ),
    FallbackDirectory(
        ip="64.65.1.185",
        orport=443,
        fingerprint="1C47BDDCE3618F6C9FC4F90D2D7E2B5FCD40AD6C",
        nickname="playafly",
    ),
    FallbackDirectory(
        ip="140.238.255.68",
        orport=443,
        fingerprint="26BB860977EE6FE3F52F9E7452D04A28F45D6FD9",
        nickname="acabworldwide2",
    ),
    FallbackDirectory(
        ip="192.42.116.201",
        orport=9001,
        fingerprint="4E93A68717B358B594F7ABAA5742D5EFE0E3E0C6",
        nickname="NTH38R2",
        ipv6_address="[2001:67c:e60:c0c:192:42:116:201]:9001",
    ),
    FallbackDirectory(
        ip="84.251.69.149",
        orport=9001,
        fingerprint="18582D11115B9CA4122101A3AF39F30A802B1B4B",
        nickname="zer0bitz",
        ipv6_address="[2001:2003:f745:9500::bad:da7a]:9001",
    ),
    FallbackDirectory(
        ip="64.65.62.17",
        orport=443,
        fingerprint="20B1B5FC996C4F48BF1B615B7472ED498D985DF1",
        nickname="recycledj",
    ),
    FallbackDirectory(
        ip="45.63.15.42",
        orport=443,
        fingerprint="8E9E3239EC9A082F5337C5F45A8E706A86BA19B0",
        nickname="zubrowka",
    ),
    FallbackDirectory(
        ip="23.163.216.135",
        orport=443,
        fingerprint="2683A6EB5F2DAB673CE92858904862EE1CEB4CB7",
        nickname="mkn7787relay0",
        ipv6_address="[2602:ffd1:7:6b::a]:443",
    ),
    FallbackDirectory(
        ip="109.192.104.34",
        orport=443,
        fingerprint="1E6C798C8624780A977EA758A200C0296EC9CA6A",
        nickname="fluppi",
        ipv6_address="[2a02:8071:5f00:31a0:20d:48ff:fe5f:b239]:9001",
    ),
    FallbackDirectory(
        ip="160.119.249.240",
        orport=443,
        fingerprint="8428C02CCD1CF01715C91F1819BA507C1A79A931",
        nickname="dani",
    ),
    FallbackDirectory(
        ip="180.13.1.145",
        orport=4001,
        fingerprint="7435AF094B162CAE8904850F13BD79786BB54D1B",
        nickname="cuccnl10G",
    ),
    FallbackDirectory(
        ip="88.80.26.3",
        orport=443,
        fingerprint="C90A7324D99F311B4AB1C3DE15CF1DDD4C56FF31",
        nickname="PRQseTORexit4",
        ipv6_address="[2a00:16b0:1:243::7012:e817]:443",
    ),
    FallbackDirectory(
        ip="77.20.42.234",
        orport=443,
        fingerprint="6428176DC76120CE8EF980595539130F9D40AC0D",
        nickname="Ponyhof",
    ),
    FallbackDirectory(
        ip="31.184.236.104",
        orport=9001,
        fingerprint="48407E7B3AA2E3F3B7DC7980F2D76479489AF0F5",
        nickname="koob0927",
    ),
    FallbackDirectory(
        ip="64.65.1.8",
        orport=443,
        fingerprint="2AF9C0C8AE27CC0D6694BF139F961CCA6B8C5757",
        nickname="diamondatl",
    ),
    FallbackDirectory(
        ip="145.239.136.129",
        orport=8080,
        fingerprint="D5146BA3FF0C4F3EFAE486BD1F693C2B786AA8AF",
        nickname="Starfleet",
    ),
    FallbackDirectory(
        ip="198.50.191.95",
        orport=443,
        fingerprint="39F096961ED2576975C866D450373A9913AFDC92",
        nickname="shhovh",
    ),
    FallbackDirectory(
        ip="37.114.53.9",
        orport=9001,
        fingerprint="26E3C67C9BB4B9303B01452AF9E71455686D241B",
        nickname="SkibidiCrackhead",
        ipv6_address="[2a12:3e80:400:8::]:9001",
    ),
    FallbackDirectory(
        ip="193.200.229.34",
        orport=1080,
        fingerprint="286F53DD87AEE0B085C34F34259AFC0B09A259FC",
        nickname="kodakblack",
    ),
    FallbackDirectory(
        ip="80.67.172.162",
        orport=9001,
        fingerprint="59F2831A9BEB7AB3D5803445F946EA9FEEEFA217",
        nickname="algrothendieck2",
    ),
    FallbackDirectory(
        ip="50.54.51.20",
        orport=9001,
        fingerprint="C5BB82D7E0491C48B1F1E2E09B98FF1C95C205F5",
        nickname="NICKNET",
    ),
    FallbackDirectory(
        ip="203.31.40.236",
        orport=443,
        fingerprint="D3A55B115FC350DF5A26FFB2C098EB0B30456CAE",
        nickname="Aramis",
    ),
    FallbackDirectory(
        ip="107.175.59.252",
        orport=443,
        fingerprint="0F5A78ECBA449016B00F05A85398D5AD3DC7A895",
        nickname="YoungBrother2",
    ),
    FallbackDirectory(
        ip="5.2.78.126",
        orport=9001,
        fingerprint="E5DEA9F6570207DB9841CA04C240BCDCFEC3200D",
        nickname="Unnamed",
    ),
    FallbackDirectory(
        ip="185.165.169.239",
        orport=443,
        fingerprint="CD94752BFBC94EC82F081B86E95241BB71D7CF99",
        nickname="impishingyserawn",
    ),
    FallbackDirectory(
        ip="45.141.215.238",
        orport=8430,
        fingerprint="34B80D703F4D6350146B684E66D962A23A830117",
        nickname="Quetzalcoatl",
        ipv6_address="[2a12:a800:2:1:45:141:215:238]:8430",
    ),
    FallbackDirectory(
        ip="192.42.116.188",
        orport=8080,
        fingerprint="45B06605BD7AB37BFE0452767706B98559517526",
        nickname="NTH36R7",
        ipv6_address="[2001:67c:e60:c0c:192:42:116:188]:8080",
    ),
    FallbackDirectory(
        ip="82.149.227.236",
        orport=9003,
        fingerprint="67E7B7D4BFCB1E0B4DF2CDB33B1FDE4B69C9DD62",
        nickname="f14480488695e0c7b27",
    ),
    FallbackDirectory(
        ip="64.65.62.242",
        orport=443,
        fingerprint="B7859ED84EFEE8FF8267587580A1A7CCCE2CB82E",
        nickname="jkwon",
    ),
    FallbackDirectory(
        ip="45.90.4.235",
        orport=9001,
        fingerprint="F475E5987E44A2B7B143A2BEE3F8128EEFD7E5A3",
        nickname="0x1ea7deadbeef",
        ipv6_address="[2a03:4000:58:7d:de1:ea7:dead:beef]:9090",
    ),
    FallbackDirectory(
        ip="109.70.100.245",
        orport=80,
        fingerprint="38B0226F4318EEB45D4D6777E18A17B50615F3A5",
        nickname="bender",
        ipv6_address="[2a03:e600:100:c3::10]:80",
    ),
    FallbackDirectory(
        ip="217.160.114.102",
        orport=9001,
        fingerprint="4C122DFAED8BD43AD63BB1045AF53A9708F17695",
        nickname="RelayUli",
    ),
    FallbackDirectory(
        ip="64.65.1.39",
        orport=443,
        fingerprint="A9EA412E9035B285D68EAA994FADFB1EF49324D8",
        nickname="parlaed4l",
    ),
    FallbackDirectory(
        ip="93.95.231.88",
        orport=9001,
        fingerprint="9DFF7F006FA33615DADD4EA775E1CEF73E7D7630",
        nickname="keepingfaith",
    ),
    FallbackDirectory(
        ip="95.217.112.245",
        orport=443,
        fingerprint="A2CD32D9D0668DB764AD68C745CE29693CA851B9",
        nickname="arbitraryTessa0",
        ipv6_address="[2a01:4f9:4a:2e4e::2]:443",
    ),
    FallbackDirectory(
        ip="160.119.253.114",
        orport=443,
        fingerprint="17919460EFE0DFC2B0CF0D6C453AC72B252630F5",
        nickname="lon",
    ),
    FallbackDirectory(
        ip="38.135.24.30",
        orport=9002,
        fingerprint="EC36350A0239EAFB1D5626816EED167123C4B3CD",
        nickname="NeelTorExit1A",
        ipv6_address="[2602:f6f6:2:ad5c::1]:9002",
    ),
    FallbackDirectory(
        ip="103.149.168.242",
        orport=9001,
        fingerprint="E7017A361C44F7403B186E812C48A06916AD5D83",
        nickname="as215248node7",
        ipv6_address="[2a14:38c0:1::242]:9001",
    ),
    FallbackDirectory(
        ip="159.69.11.74",
        orport=1050,
        fingerprint="8CF9D1663EC7FC79BFF31AEAC1C907D075153470",
        nickname="OkurwaRelay",
        ipv6_address="[2a01:4f8:1c1c:31b5::1]:1050",
    ),
    FallbackDirectory(
        ip="51.81.201.207",
        orport=143,
        fingerprint="A9A567CC15293CD3CD6B2BC12A435F37731843A2",
        nickname="Echidna4",
        ipv6_address="[2604:2dc0:202:300::cd0]:143",
    ),
    FallbackDirectory(
        ip="5.104.84.183",
        orport=143,
        fingerprint="F1467AA85A0CDDE645EC690A9602095E63AFF097",
        nickname="Quetzalcoatl",
        ipv6_address="[2400:d320:2261:6860::1]:143",
    ),
    FallbackDirectory(
        ip="185.40.4.149",
        orport=9004,
        fingerprint="E0AE4772051D74DE4DC1A525D9670BC12ED2EDAF",
        nickname="4727",
        ipv6_address="[2a0e:4005:1002:ffff:185:40:4:149]:9004",
    ),
    FallbackDirectory(
        ip="37.114.57.163",
        orport=9001,
        fingerprint="E8B91980497DF39125A8F713135EAE761E6E0897",
        nickname="napster",
    ),
    FallbackDirectory(
        ip="209.58.180.236",
        orport=9001,
        fingerprint="0371E4EC901C4FC77FEA2AA5BE4218F0BE1F6CE3",
        nickname="hong",
    ),
    FallbackDirectory(
        ip="38.135.24.32",
        orport=9002,
        fingerprint="E0711FF93A8655D7CE5485240A0B7AF19CE512C8",
        nickname="NeelTorExit3A",
        ipv6_address="[2602:f6f6:2:d31a::1]:9002",
    ),
    FallbackDirectory(
        ip="51.89.23.41",
        orport=9000,
        fingerprint="D0EDEFA81312D510D61666904120A762681A82A1",
        nickname="prsv",
    ),
    FallbackDirectory(
        ip="5.45.104.176",
        orport=9000,
        fingerprint="AA4644F0EC589EEA2F501BB867E32E599F8169DA",
        nickname="Quetzalcoatl",
        ipv6_address="[2a03:4000:6:102b:c457:f3ff:feb0:a6d0]:9000",
    ),
]


def get_fallbacks() -> list[FallbackDirectory]:
    """Get list of fallback directories."""
    return FALLBACK_DIRECTORIES


def get_random_fallback() -> FallbackDirectory:
    """Get a random fallback directory."""
    return random.choice(FALLBACK_DIRECTORIES)


def get_shuffled_fallbacks() -> list[FallbackDirectory]:
    """Get all fallback directories in random order."""
    fallbacks = list(FALLBACK_DIRECTORIES)
    random.shuffle(fallbacks)
    return fallbacks
